==> dronesploit-1.1.12.tar.gz: dronesploit-1.1.12/README.md <==
<p align="center"><img src="https://github.com/dhondta/dronesploit/raw/master/docs/pages/img/logo.png"></p>
<h1 align="center">DroneSploit <a href="https://twitter.com/intent/tweet?text=DroneSploit%20-%20Console%20made%20with%20SploitKit%20for%20hacking%20light%20commercial%20drones.%0D%0Ahttps%3a%2f%2fgithub%2ecom%2fdhondta%2fdronesploit%0D%0A&hashtags=python,console,sploitkit,dronehacking,dronepentesting"><img src="https://img.shields.io/badge/Tweet--lightgrey?logo=twitter&style=social" alt="Tweet" height="20"/></a></h1>
<h3 align="center">Easily pentest drones.</h3>

[![PyPi](https://img.shields.io/pypi/v/dronesploit.svg)](https://pypi.python.org/pypi/dronesploit/)
[![Read The Docs](https://readthedocs.org/projects/dronesploit/badge/?version=latest)](https://dronesploit.readthedocs.io/en/latest/?badge=latest)
[![Python Versions](https://img.shields.io/pypi/pyversions/dronesploit.svg)](https://pypi.python.org/pypi/dronesploit/)
[![Requirements Status](https://requires.io/github/dhondta/dronesploit/requirements.svg?branch=master)](https://requires.io/github/dhondta/dronesploit/requirements/?branch=master)
[![Known Vulnerabilities](https://snyk.io/test/github/dhondta/dronesploit/badge.svg?targetFile=requirements.txt)](https://snyk.io/test/github/dhondta/dronesploit?targetFile=requirements.txt)
[![DOI](https://zenodo.org/badge/207086727.svg)](https://zenodo.org/badge/latestdoi/207086727)
[![Black Hat Arsenal Europe 2019](https://img.shields.io/badge/Black%20Hat%20Arsenal-EU%202019-blue.svg)](https://www.blackhat.com/eu-19/arsenal/schedule/index.html#drone-hacking-with-dronesploit-18217)
[![License](https://img.shields.io/badge/license-AGPL%20v3-lightgrey.svg)](https://github.com/dhondta/dronesploit/blob/master/LICENSE)


This CLI framework is based on [`sploitkit`](https://github.com/dhondta/python-sploitkit/) and is an attempt to gather hacking techniques and exploits especially focused on **drone hacking**. For the ease of use, the interface has a layout that looks like Metasploit.

```sh
pip3 install dronesploit
```

> :warning: When starting up the framework, you may have every modules **disabled**. You can see why by using the `show issues` command. Modules are disabled when they have unsatisfied requirements, i.e. `aircrack-ng` not installed.

## Documentation

- [Black Hat Europe Arsenal 2019 presentation](https://dhondta.github.io/dronesploit/docs/pages/blackhat-eu19-arsenal.pdf)
- [*Black Hat Europe: New tool offers Metasploit-like framework for hacking into drones*, The Daily Swig](https://portswigger.net/daily-swig/black-hat-europe-new-tool-offers-metasploit-like-framework-for-hacking-into-drones)
- [*Dronesploit, a pentesting console framework dedicated to drones*, Hakin9](https://hakin9.org/dronesploit-a-pentesting-console-framework-dedicated-to-drones/)


## Basics

### Interface

<p align="center"><img src="https://github.com/dhondta/dronesploit/raw/master/docs/pages/img/dronesploit.png"></p>
<p align="center"><img src="https://github.com/dhondta/dronesploit/raw/master/docs/pages/img/dronesploit-commands.png"></p>

### Modules

This example shows an example of module for DroneSploit aimed to change the password or the SSID of a particular model of drone.

<p align="center"><img src="https://github.com/dhondta/dronesploit/raw/master/docs/pages/img/dronesploit-module.png"></p>

==> dronesploit-1.1.13.tar.gz: dronesploit-1.1.13/README.md <==
<p align="center"><img src="https://github.com/dhondta/dronesploit/raw/main/docs/pages/img/logo.png"></p>
<h1 align="center">DroneSploit <a href="https://twitter.com/intent/tweet?text=DroneSploit%20-%20Console%20made%20with%20SploitKit%20for%20hacking%20light%20commercial%20drones.%0D%0Ahttps%3a%2f%2fgithub%2ecom%2fdhondta%2fdronesploit%0D%0A&hashtags=python,console,sploitkit,dronehacking,dronepentesting"><img src="https://img.shields.io/badge/Tweet--lightgrey?logo=twitter&style=social" alt="Tweet" height="20"/></a></h1>
<h3 align="center">Easily pentest drones.</h3>

[![PyPi](https://img.shields.io/pypi/v/dronesploit.svg)](https://pypi.python.org/pypi/dronesploit/)
[![Read The Docs](https://readthedocs.org/projects/dronesploit/badge/?version=latest)](https://dronesploit.readthedocs.io/en/latest/?badge=latest)
[![Python Versions](https://img.shields.io/pypi/pyversions/dronesploit.svg)](https://pypi.python.org/pypi/dronesploit/)
[![Requirements Status](https://requires.io/github/dhondta/dronesploit/requirements.svg?branch=main)](https://requires.io/github/dhondta/dronesploit/requirements/?branch=main)
[![Known Vulnerabilities](https://snyk.io/test/github/dhondta/dronesploit/badge.svg?targetFile=requirements.txt)](https://snyk.io/test/github/dhondta/dronesploit?targetFile=requirements.txt)
[![DOI](https://zenodo.org/badge/207086727.svg)](https://zenodo.org/badge/latestdoi/207086727)
[![Black Hat Arsenal Europe 2019](https://img.shields.io/badge/Black%20Hat%20Arsenal-EU%202019-blue.svg)](https://www.blackhat.com/eu-19/arsenal/schedule/index.html#drone-hacking-with-dronesploit-18217)
[![License](https://img.shields.io/badge/license-AGPL%20v3-lightgrey.svg)](https://github.com/dhondta/dronesploit/blob/main/LICENSE)


This CLI framework is based on [`sploitkit`](https://github.com/dhondta/python-sploitkit/) and is an attempt to gather hacking techniques and exploits especially focused on **drone hacking**. For the ease of use, the interface has a layout that looks like Metasploit.

```sh
pip3 install dronesploit
```

> :warning: When starting up the framework, you may have every modules **disabled**. You can see why by using the `show issues` command. Modules are disabled when they have unsatisfied requirements, i.e. `aircrack-ng` not installed.

## Documentation

- [Black Hat Europe Arsenal 2019 presentation](https://dhondta.github.io/dronesploit/docs/pages/blackhat-eu19-arsenal.pdf)
- [*Black Hat Europe: New tool offers Metasploit-like framework for hacking into drones*, The Daily Swig](https://portswigger.net/daily-swig/black-hat-europe-new-tool-offers-metasploit-like-framework-for-hacking-into-drones)
- [*Dronesploit, a pentesting console framework dedicated to drones*, Hakin9](https://hakin9.org/dronesploit-a-pentesting-console-framework-dedicated-to-drones/)


## Basics

### Interface

<p align="center"><img src="https://github.com/dhondta/dronesploit/raw/main/docs/pages/img/dronesploit.png"></p>
<p align="center"><img src="https://github.com/dhondta/dronesploit/raw/main/docs/pages/img/dronesploit-commands.png"></p>

### Modules

This example shows an example of module for DroneSploit aimed to change the password or the SSID of a particular model of drone.

<p align="center"><img src="https://github.com/dhondta/dronesploit/raw/main/docs/pages/img/dronesploit-module.png"></p>
